#
# spec file for package python3-requests
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           python3-requests
Version:        2.7.0
Release:        5.1
Url:            http://python-requests.org
Summary:        Awesome Python HTTP Library That's Actually Usable
License:        Apache-2.0 and LGPL-2.1+ and MIT
Group:          Development/Languages/Python
#TODO/FIXME: Maybe split out charade and urllib3 into sub-packages to simplify:
Source:         http://pypi.python.org/packages/source/r/requests/requests-%{version}.tar.gz
# PATCH-FIX-OPENSUSE python3-requests-boo912903-default-cacert.patch boo912903 federico@suse.com -- completely ignore the internal CA bundle; use openSUSE's system CA bundle
Patch0:         python3-requests-boo912903-default-cacert.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python3
BuildRequires:  python3-devel
BuildRequires:  python3-py
BuildRequires:  python3-setuptools
Requires:       python3-py
BuildArch:      noarch

%description
Requests is an ISC Licensed HTTP library, written in Python, for human
beings.

Most existing Python modules for sending HTTP requests are extremely
verbose and cumbersome. Python's builtin urllib2 module provides most of
the HTTP capabilities you should need, but the api is thoroughly broken.
It requires an enormous amount of work (even method overrides) to
perform the simplest of tasks.

Features:

- Extremely simple GET, HEAD, POST, PUT, DELETE Requests
    + Simple HTTP Header Request Attachment
    + Simple Data/Params Request Attachment
    + Simple Multipart File Uploads
    + CookieJar Support
    + Redirection History
    + Redirection Recursion Urllib Fix
    + Auto Decompression of GZipped Content
    + Unicode URL Support
- Simple Authentication
    + Simple URL + HTTP Auth Registry

%prep
%setup -q -n requests-%{version}
# For rpmlint warning: remove shebang from python library:
sed -i '/^#!/d' ./requests/certs.py
%patch0 -p1
rm ./requests/cacert.pem

%build
python3 setup.py build

%check
python3 setup.py test

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}

%files
%defattr(-,root,root)
%doc README.rst HISTORY.rst LICENSE NOTICE
%{python3_sitelib}/*

%changelog
* Mon Jan 30 2017 matwey.kornilov@gmail.com
- Removed no-default-cacert.patch, no-default-cacert-sles.patch.
- Added python3-requests-boo912903-default-cacert.patch for
  boo#912903.  This makes https requests use verification based
  on openSUSE's default CA bundle.  This didn't work at all before.
* Sat May  9 2015 arun@gmx.de
- update to version 2.7.0:
  * Updated urllib3 to 1.10.4, resolving several bugs involving
    chunked transfer encoding and response framing.
* Sat Apr 25 2015 arun@gmx.de
- update to version 2.6.2:
  * Fix regression where compressed data that was sent as chunked data
    was not properly decompressed. (#2561)
* Thu Apr 23 2015 arun@gmx.de
- update to version 2.6.1:
  * Remove VendorAlias import machinery introduced in v2.5.2.
  * Simplify the PreparedRequest.prepare API: We no longer require the
    user to pass an empty list to the hooks keyword
    argument. (c.f. #2552)
  * Resolve redirects now receives and forwards all of the original
    arguments to the adapter. (#2503)
  * Handle UnicodeDecodeErrors when trying to deal with a unicode URL
    that cannot be encoded in ASCII. (#2540)
  * Populate the parsed path of the URI field when performing Digest
    Authentication. (#2426)
  * Copy a PreparedRequest’s CookieJar more reliably when it is not an
    instance of RequestsCookieJar. (#2527)
* Sat Mar 14 2015 arun@gmx.de
- update to version 2.6.0:
  * Fix handling of cookies on redirect. Previously a cookie without a
    host value set would use the hostname for the redirected URL
    exposing requests users to session fixation attacks and
    potentially cookie stealing. This was disclosed privately by
    Matthew Daley of BugFuzz. An CVE identifier has not yet been
    assigned for this. This affects all versions of requests from
    v2.1.0 to v2.5.3 (inclusive on both ends).
  * Fix error when requests is an install_requires dependency and
    python setup.py test is run. (#2462)
  * Fix error when urllib3 is unbundled and requests continues to use
    the vendored import location.
  * Include fixes to urllib3‘s header handling.
  * Requests’ handling of unvendored dependencies is now more
    restrictive.
  * Support bytearrays when passed as parameters in the files
    argument. (#2468)
  * Avoid data duplication when creating a request with str, bytes, or
    bytearray input to the files argument.
* Thu Feb 26 2015 arun@gmx.de
- update to version 2.5.3:
  * Revert changes to our vendored certificate bundle. For more
    context see (#2455, #2456, and http://bugs.python.org/issue23476)
- changes from version 2.5.2:
  * Features and Improvements
  - Add sha256 fingerprint support. (shazow/urllib3#540)
  - Improve the performance of headers. (shazow/urllib3#544)
  * Bugfixes
  - Copy pip’s import machinery. When downstream redistributors
    remove requests.packages.urllib3 the import machinery will
    continue to let those same symbols work. Example usage in
    requests’ documentation and 3rd-party libraries relying on the
    vendored copies of urllib3 will work without having to fallback
    to the system urllib3.
  - Attempt to quote parts of the URL on redirect if unquoting and
    then quoting fails. (#2356)
  - Fix filename type check for multipart form-data uploads. (#2411)
  - Properly handle the case where a server issuing digest
    authentication challenges provides both auth and auth-int
    qop-values. (#2408)
  - Fix a socket leak. (shazow/urllib3#549)
  - Fix multiple Set-Cookie headers properly. (shazow/urllib3#534)
  - Disable the built-in hostname verification. (shazow/urllib3#526)
  - Fix the behaviour of decoding an exhausted
    stream. (shazow/urllib3#535)
  * Security
  - Pulled in an updated cacert.pem.
  - Drop RC4 from the default cipher list. (shazow/urllib3#551)
* Sat Jan 17 2015 arun@gmx.de
- specfile: update copyright year
- update to version 2.5.1:
  * Only catch HTTPErrors in raise_for_status (#2382)
  * Handle LocationParseError from urllib3 (#2344)
  * Handle file-like object filenames that are not strings (#2379)
  * Unbreak HTTPDigestAuth handler. Allow new nonces to be negotiated
    (#2389)
- changes from version 2.5.0:
  * Allow usage of urllib3's Retry object with HTTPAdapters (#2216)
  * The iter_lines method on a response now accepts a delimiter with
    which to split the content (#2295)
  * Add deprecation warnings to functions in requests.utils that will
    be removed in 3.0 (#2309)
  * Sessions used by the functional API are always closed (#2326)
  * Restrict requests to HTTP/1.1 and HTTP/1.0 (stop accepting
    HTTP/0.9) (#2323)
  * Only parse the URL once (#2353)
  * Allow Content-Length header to always be overriden (#2332)
  * Properly handle files in HTTPDigestAuth (#2333)
  * Cap redirect_cache size to prevent memory abuse (#2299)
  * Fix HTTPDigestAuth handling of redirects after authenticating
    successfully (#2253)
  * Fix crash with custom method parameter to Session.request (#2317)
  * Fix how Link headers are parsed using the regular expression
    library (#2271)
  * Add more references for interlinking (#2348)
  * Update CSS for theme (#2290)
  * Update width of buttons and sidebar (#2289)
  * Replace references of Gittip with Gratipay (#2282)
  * Add link to changelog in sidebar (#2273)
- changes from version 2.4.3:
  * Unicode URL improvements for Python 2.
  * Re-order JSON param for backwards compat.
  * Automatically defrag authentication schemes from host/pass
    URIs. (#2249)
- changes from version 2.4.2:
  * FINALLY! Add json parameter for uploads! (#2258)
  * Support for bytestring URLs on Python 3.x (#2238)
  * Avoid getting stuck in a loop (#2244)
  * Multiple calls to iter* fail with unhelpful error. (#2240, #2241)
  * Correct redirection introduction (#2245)
  * Added example of how to send multiple files in one
    request. (#2227)
  * Clarify how to pass a custom set of CAs (#2248)
* Thu Sep 11 2014 toddrme2178@gmail.com
- Update to 2.4.1 (2014-09-09)
  - Now has a "security" package extras set,
    ``$ pip install requests[security]``
  - Requests will now use Certifi if it is available.
  - Capture and re-raise urllib3 ProtocolError
  - Bugfix for responses that attempt to redirect to themselves
    forever (wtf?).
- Update to 2.4.0 (2014-08-29)
  * Behavioral Changes
  - ``Connection: keep-alive`` header is now sent automatically.
  * Improvements
  - Support for connect timeouts! Timeout now accepts a tuple
    (connect, read) which is used to set individual connect and
    read timeouts.
  - Allow copying of PreparedRequests without headers/cookies.
  - Updated bundled urllib3 version.
  - Refactored settings loading from environment
    new `Session.merge_environment_settings`.
  - Handle socket errors in iter_content.
* Wed Jul 16 2014 p.drouand@gmail.com
- Replace python3-distribute with python3-setuptools requirement
- Use tarball from pypi
* Thu Jun 12 2014 rschweikert@suse.com
- Update to version 2.3.0
  + New ``Response`` property ``is_redirect``, which is true when the
    library could have processed this response as a redirection (whether
    or not it actually did).
  + The ``timeout`` parameter now affects requests with both ``stream=True``
    and ``stream=False`` equally.
  + The change in v2.0.0 to mandate explicit proxy schemes has been reverted.
    Proxy schemes now default to ``http://``.
  + The ``CaseInsensitiveDict`` used for HTTP headers now behaves like a normal
    dictionary when references as string or viewd in the interpreter.
  + No longer expose Authorization or Proxy-Authorization headers on redirect.
    Fix CVE-2014-1829 and CVE-2014-1830 respectively.
  + Authorization is re-evaluated each redirect.
  + On redirect, pass url as native strings.
  + Fall-back to autodetected encoding for JSON when Unicode detection fails.
  + Headers set to ``None`` on the ``Session`` are now correctly not sent.
  + Correctly honor ``decode_unicode`` even if it wasn't used earlier in the
    same response.
  + Stop advertising ``compress`` as a supported Content-Encoding.
  + The ``Response.history`` parameter is now always a list.
  + Many, many ``urllib3`` bugfixes.- Fixes incorrect parsing of proxy
    credentials that contain a literal or encoded '#' character.
  + Assorted urllib3 fixes.
  + New exception: ``ContentDecodingError``. Raised instead of ``urllib3``
    ``DecodeError`` exceptions.
  + Avoid many many exceptions from the buggy implementation of
    ``proxy_bypass`` on OS X in Python 2.6.
  + Avoid crashing when attempting to get authentication credentials
    from ~/.netrc when running as a user without a home directory.
  + Use the correct pool size for pools of connections to proxies.
  + Fix iteration of ``CookieJar`` objects.
  + Ensure that cookies are persisted over redirect.
  + Switch back to using chardet, since it has merged with charade.
  + Cookies set on individual Requests through a ``Session``
    (e.g. via ``Session.get()``) are no longer persisted to the ``Session``.
  + Clean up connections when we hit problems during chunked upload,
    rather than leaking them.
  + Return connections to the pool when a chunked upload is successful,
    rather than leaking it.
  + Match the HTTPbis recommendation for HTTP 301 redirects.
  + Prevent hanging when using streaming uploads and Digest Auth when a
    401 is received.
  + Values of headers set by Requests are now always the native string type.
  + Fix previously broken SNI support.
  + Fix accessing HTTP proxies using proxy authentication.
  + Unencode HTTP Basic usernames and passwords extracted from URLs.
  + Support for IP address ranges for no_proxy environment variable
  + Parse headers correctly when users override the default ``Host:`` header.
  + Avoid munging the URL in case of case-sensitive servers.
  + Looser URL handling for non-HTTP/HTTPS urls.
  + Accept unicode methods in Python 2.6 and 2.7.
  + More resilient cookie handling.
  + Make ``Response`` objects pickleable.
  + Actually added MD5-sess to Digest Auth instead of pretending to like
    last time.
  + Updated internal urllib3.
  + Fixed @Lukasa's lack of taste.
- Add no-default-cacert-sles.patch: use this patch when building
  for SLES, since python in SLES and openSUSE behave differently
  when it comes to SSL, and no-default-cacert.patch is wrong for
  SLES.
- Update no-default-cacert.patch
* Fri Oct 11 2013 p.drouand@gmail.com
- Don't remove python-setuptools metadata directory; only unwanted file
* Wed Sep 25 2013 p.drouand@gmail.com
- Update to version 2.0.0
  API Changes:
  + Keys in the Headers dictionary are now native strings on all Python
    versions, i.e. bytestrings on Python 2, unicode on Python 3.
  + Proxy URLs now must have an explicit scheme. A MissingSchema exception
    will be raised if they don't.
  + Timeouts now apply to read time if Stream=False.
  + RequestException is now a subclass of IOError, not RuntimeError.
  + Added new method to PreparedRequest objects: PreparedRequest.copy().
  + Added new method to Session objects: Session.update_request(). This
    method updates a Request object with the data (e.g. cookies) stored on the Session.
  + Added new method to Session objects: Session.prepare_request(). This method
    updates and prepares a Request object, and returns the corresponding PreparedRequest
    object.
  + Added new method to HTTPAdapter objects: HTTPAdapter.proxy_headers().
    This should not be called directly, but improves the subclass interface.
  + httplib.IncompleteRead exceptions caused by incorrect chunked encoding will
    now raise a Requests ChunkedEncodingError instead.
  + Invalid percent-escape sequences now cause a Requests InvalidURL
    exception to be raised.
  + HTTP 208 no longer uses reason phrase "im_used". Correctly uses "already_reported".
  + HTTP 226 reason added ("im_used").
  Bugfixes:
  + Vastly improved proxy support, including the CONNECT verb.
  + Cookies are now properly managed when 401 authentication responses are received.
  + Chunked encoding fixes.
  + Support for mixed case schemes.
  + Better handling of streaming downloads.
  + Retrieve environment proxies from more locations.
  + Minor cookies fixes.
  + Imroved redirect behaviour.
  + Improved streaming behaviour, particularly for compressed data.
  + Miscellaneous small Python 3 text encoding bugs.
  + .netrc no longer overrides explicit auth.
  + Cookies set by hooks are now correctly persisted on Sessions.
  + Fix problem with cookies that specify port numbers in their host field.
  + BytesIO can be used to perform streaming uploads.
  + More generous parsing of the no_proxy environment variable.
  + Non-string objects can be passed in data values alongside files.
* Thu Jul 25 2013 vuntz@suse.com
- Add no-default-cacert.patch: completely ignore the internal CA
  bundle and point to /etc/ssl/certs/. This works because we
  patched python to do the right thing when a directory is used
  there instead of a file.
- Manually remove requests/cacert.pem (better than doing that in
  the patch, since it's big) too.
* Mon May 13 2013 dmueller@suse.com
- update to 1.2.0:
  * Fixed cookies on sessions and on requests
  * Significantly change how hooks are dispatched - hooks now receive all the
  arguments specified by the user when making a request so hooks can make a
  secondary request with the same parameters. This is especially necessary for
  authentication handler authors
  * certifi support was removed
  * Fixed bug where using OAuth 1 with body ``signature_type`` sent no data
  * Major proxy work thanks to @Lukasa including parsing of proxy authentication
  from the proxy url
  * Fix DigestAuth handling too many 401s
  * Update vendored urllib3 to include SSL bug fixes
  * Allow keyword arguments to be passed to ``json.loads()`` via the
  ``Response.json()`` method
  * Don't send ``Content-Length`` header by default on ``GET`` or ``HEAD``
  requests
  * Add ``elapsed`` attribute to ``Response`` objects to time how long a request
  took.
  * Fix ``RequestsCookieJar``
  * Sessions and Adapters are now picklable, i.e., can be used with the
  mutiprocessing library
  Update charade to version 1.0.3
* Fri Jan 18 2013 saschpe@suse.de
- Set license to "Apache-2.0 and LGPL-2.1+ and MIT", according to
  https://github.com/kennethreitz/requests/issues/1111, the base
  license is Apache-2.0 but requests ships two libraries (bnc#799119):
  + charade: LGPL-2.1+
  + urllib3: MIT
* Tue Jan 15 2013 p.drouand@gmail.com
- Initial python3 support
